h-news parsing tests

# h-news parsing tests ‐ change logs

The files in this directory where designed to test the parsing of h-news.

## Change log:

- Update text output to be textContent non-trimmed for all and minimum tests ‐ 29 May 2015 by Glenn Jones
- Changed author property to an array for all and minimum tests. Also added missing summary property to minimum test. ‐ 23 May 2015 by Glenn Jones
- Broke old HTML format into small files to aid simpler testing ‐ 21 May 2015 by Glenn Jones
- Updated JSON examples so it always has the rel={} object as well as the items=[] array ‐ 21 November 2013 by Glenn Jones
- Updated encoding issue on e-* ‐ 19 September 2013 by Glenn Jones
- Created ‐ 14 January 2013 by Glenn Jones
- Updated encoding issue on e-* ‐ 19 September 2013 by Glenn Jones

## Contributors:

- Glenn Jones